@@ -15,7 +15,7 @@
 #endif
 
 #ifndef HAVE_CLOCK_GETTIME
-int clock_gettime(clockid_t clk_id UNUSED, struct timespec *tp)
+int clock_gettime(clockid_t clk_id UNUSED, struct timespec *ts)
 {
 #ifdef __MACH__ // OS X does not have clock_gettime, use clock_get_time
     clock_serv_t cclock;
@@ -23,14 +23,14 @@ int clock_gettime(clockid_t clk_id UNUSED, struct timespec *tp)
     host_get_clock_service(mach_host_self(), CALENDAR_CLOCK, &cclock);
     clock_get_time(cclock, &mts);
     mach_port_deallocate(mach_task_self(), cclock);
-    tp->tv_sec = mts.tv_sec;
-    tp->tv_nsec = mts.tv_nsec;
+    ts->tv_sec = mts.tv_sec;
+    ts->tv_nsec = mts.tv_nsec;
 #else
     struct timeval tv;
     if (gettimeofday(&tv, NULL) < 0)
 	return -1;
-    tp->ts_sec = tv.tv_sec;
-    tp->ts_nsec = tv.tv_usec * 1000;
+    ts->tv_sec = tv.tv_sec;
+    ts->tv_nsec = tv.tv_usec * 1000;
     /* paranoid programming */
     if (1000000 <= (tv)->tv_usec) {
 	(tv)->tv_usec -= 1000000;
