@@ -115,6 +115,15 @@ def main(starting_number_of_options=0):
                 with open('failed_build_configs.txt', 'a') as failed_configs:
                     failed_configs.write(' '.join(command) + '\n')
 
+            if retval == 0:
+                command = ['scons', 'check']
+                command.extend(params)
+                retval = subprocess.call(command, stdout=dev_null)
+                if retval != 0:
+                    print command
+                with open('check_build_configs.txt', 'a') as failed_configs:
+                    failed_configs.write(str(retval) + ' ' + ' '.join(command) + '\n')
+
     return failed_configurations
 
 if __name__ == '__main__':
