@@ -15,17 +15,17 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int gps_sock_open(/*@null@*/const char *, /*@null@*/const char *,
-		      /*@out@*/struct gps_data_t *);
+extern int gps_sock_open(const char *, const char *,
+		      struct gps_data_t *);
 extern int gps_sock_close(struct gps_data_t *);
 extern int gps_sock_send(struct gps_data_t *, const char *);
-extern int gps_sock_read(/*@out@*/struct gps_data_t *);
+extern int gps_sock_read(struct gps_data_t *);
 extern bool gps_sock_waiting(const struct gps_data_t *, int);
-extern int gps_sock_stream(struct gps_data_t *, unsigned int, /*@null@*/void *);
-extern const char /*@observer@*/ *gps_sock_data(const struct gps_data_t *);
+extern int gps_sock_stream(struct gps_data_t *, unsigned int, void *);
+extern const char *gps_sock_data(const struct gps_data_t *);
 extern int gps_sock_mainloop(struct gps_data_t *, int,
 			      void (*)(struct gps_data_t *));
-extern int gps_shm_open(/*@out@*/struct gps_data_t *);
+extern int gps_shm_open(struct gps_data_t *);
 extern void gps_shm_close(struct gps_data_t *);
 extern bool gps_shm_waiting(const struct gps_data_t *, int);
 extern int gps_shm_read(struct gps_data_t *);
@@ -37,7 +37,7 @@ extern int gps_dbus_mainloop(struct gps_data_t *, int,
 			      void (*)(struct gps_data_t *));
 
 extern int json_ais_read(const char *, char *, size_t, struct ais_t *,
-		  /*@null@*/const char **);
+			 const char **);
 #ifdef __cplusplus
 }
 #endif
